@@ -152,6 +152,11 @@ class DDLParser(
             return True
         return False
 
+    def t_AUTOINCREMENT(self, t: LexToken):
+        r"(AUTO_INCREMENT|AUTOINCREMENT)(?i)\b"
+        t.type = "AUTOINCREMENT"
+        return self.set_last_token(t)
+
     def t_ID(self, t: LexToken):
         r"([0-9]+[.][0-9]*([e][+-]?[0-9]+)?|[0-9]\.[0-9])\w|([a-zA-Z_,0-9:><\/\\\=\-\+\~\%$@#\|&?;*\()!{}\[\]\`\[\]]+)"
         t.type = tok.symbol_tokens.get(t.value, "ID")
@@ -216,6 +221,11 @@ class DDLParser(
             for num, symbol in enumerate(delimeters_to_start):
                 if p[0].startswith(symbol) and p[0].endswith(delimeters_to_end[num]):
                     p[0] = p[0][1:-1]
+    
+    def p_id_or_string(self, p):
+        """id_or_string : id
+        | STRING"""
+        p[0] = p[1]
 
     def t_error(self, t: LexToken):
         raise DDLParserError("Unknown symbol %r" % (t.value[0],))
