@@ -1,4 +1,5 @@
 import re
+from collections import defaultdict
 from copy import deepcopy
 from typing import Any, Dict, List, Optional, Tuple, Union
 
@@ -246,7 +247,11 @@ class Column:
         if len(p_list) != 3:
             if p_list[-3] != "*":
                 # oracle can contain * in column size
-                value_0 = int(p_list[-3])
+                try:
+                    value_0 = int(p_list[-3])
+                except ValueError:
+                    # we have column like p Geometry(MultiPolygon, 26918)
+                    value_0 = p_list[-3]
             else:
                 value_0 = p_list[-3]
             size = (value_0, int(p_list[-1]))
@@ -263,16 +268,38 @@ class Column:
                 p[0][key] = value
         p_list.pop(-1)
 
+    @staticmethod
+    def check_type_parameter(size: Union[tuple, int]) -> bool:
+        if isinstance(size, tuple) and not (
+                isinstance(size[0], str) and size[0].strip() == '*') and not (
+                    isinstance(size[0], int) or isinstance(size[0], float)):
+            return True
+        return False
+    
+    @staticmethod
+    def process_oracle_type_size(p_list):
+        if p_list[-1] == ')' and p_list[-4] == '(':
+            # for Oracle sizes like 30 CHAR
+            p_list[-3] += f" {p_list[-2]}" 
+            del p_list[-2]
+        return p_list
+
     def p_column(self, p: List) -> None:
         """column : id c_type
         | column comment
         | column LP id RP
+        | column LP id id RP
         | column LP id RP c_type
         | column LP id COMMA id RP
         | column LP id COMMA id RP c_type
         """
         p[0] = self.set_base_column_propery(p)
-        p_list = remove_par(list(p))
+        p_list = list(p)
+        
+        p_list = self.process_oracle_type_size(p_list)
+        
+        p_list = remove_par(p_list)
+        
         if isinstance(p_list[-1], dict) and "type" in p_list[-1] and len(p_list) <= 3:
             p[0]["type"] = p_list[-1]["type"]
             if p_list[-1].get("property"):
@@ -288,7 +315,11 @@ class Column:
             and bool(re.match(r"[0-9]+", p_list[-1]))
             or p_list[-1] == "max"
         ):
-            p[0]["size"] = self.get_size(p_list)
+            size = self.get_size(p_list)
+            if self.check_type_parameter(size):
+                p[0]["type_parameters"] = size
+            else:
+                p[0]["size"] = size
 
     @staticmethod
     def set_property(p: List) -> List:
@@ -321,7 +352,7 @@ class Column:
         return pk, default, unique, references, nullable
 
     def p_autoincrement(self, p: List) -> None:
-        """ autoincrement : AUTO_INCREMENT"""
+        """ autoincrement : AUTOINCREMENT"""
         p[0] = {"autoincrement": True}
 
     def p_defcolumn(self, p: List) -> None:
@@ -679,10 +710,10 @@ class BaseSQL(
         return _property
 
     def p_id_equals(self, p: List) -> None:
-        """id_equals : id id id
-        | id id
+        """id_equals : id id id_or_string
+        | id id_or_string
         | id_equals COMMA
-        | id_equals COMMA id id id
+        | id_equals COMMA id id id_or_string
         | id
         | id_equals LP pid RP
         | id_equals LP pid RP id
@@ -788,11 +819,12 @@ class BaseSQL(
         | expr DEFAULT id id id
         | expr RP
         """
-        p[0] = p[1]
+        p[0] = p[1] or defaultdict(list)
         p_list = remove_par(list(p))
-
-        if p_list[-1] != ",":
+        if p_list[-1] != "," and p_list[-1] is not None:
             if "type" in p_list[-1] and "name" in p_list[-1]:
+                if not p[0].get("columns"):
+                    p[0]["columns"] = []
                 p[0]["columns"].append(p_list[-1])
             elif "check" in p_list[-1]:
                 p[0] = self.extract_check_data(p, p_list)
@@ -801,7 +833,7 @@ class BaseSQL(
                 p[0].update({"primary_key_enforced": p_list[-1]["enforced"]})
             elif 'DEFAULT' in p_list:
                 p[0].update({"default_charset": p_list[-1]})
-            else:
+            elif isinstance(p_list[-1], dict):
                 p[0].update(p_list[-1])
 
         if isinstance(p_list[-1], dict):
